@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::wales_towns;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.007';
+our $VERSION = '1.008';
 __PACKAGE__->init();
 
 our %Remote = (
@@ -43,6 +43,12 @@ Abigail, Philippe Bruhat (BooK).
 
 =item *
 
+2015-10-19 - v1.008
+
+Updated from the source web site in Acme-MetaSyntactic-Themes version 1.048.
+
+=item *
+
 2015-02-02 - v1.007
 
 Updated from the source web site in Acme-MetaSyntactic-Themes version 1.045.
@@ -208,6 +214,7 @@ Llanwrtyd_Wells
 Llanybydder
 Loughor
 Machynlleth
+Maesglas
 Maesteg
 Menai_Bridge
 Merthyr_Tydfil
